==> org.eclipse.jgit-4.6.0.201612231935-r-sources.jar: org/eclipse/jgit/internal/storage/reftree/AlwaysFailUpdate.java <==
/*
 * Copyright (C) 2016, Google Inc.
 * and other copyright owners as documented in the project's IP log.
 *
 * This program and the accompanying materials are made available
 * under the terms of the Eclipse Distribution License v1.0 which
 * accompanies this distribution, is reproduced below, and is
 * available at http://www.eclipse.org/org/documents/edl-v10.php
 *
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or
 * without modification, are permitted provided that the following
 * conditions are met:
 *
 * - Redistributions of source code must retain the above copyright
 *   notice, this list of conditions and the following disclaimer.
 *
 * - Redistributions in binary form must reproduce the above
 *   copyright notice, this list of conditions and the following
 *   disclaimer in the documentation and/or other materials provided
 *   with the distribution.
 *
 * - Neither the name of the Eclipse Foundation, Inc. nor the
 *   names of its contributors may be used to endorse or promote
 *   products derived from this software without specific prior
 *   written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 * SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT,
 * STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF
 * ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

package org.eclipse.jgit.internal.storage.reftree;

import java.io.IOException;

import org.eclipse.jgit.lib.ObjectIdRef;
import org.eclipse.jgit.lib.Ref;
import org.eclipse.jgit.lib.RefDatabase;
import org.eclipse.jgit.lib.RefUpdate;
import org.eclipse.jgit.lib.Repository;

/** Update that always rejects with {@code LOCK_FAILURE}. */
class AlwaysFailUpdate extends RefUpdate {
	private final RefTreeDatabase refdb;

	AlwaysFailUpdate(RefTreeDatabase refdb, String name) {
		super(new ObjectIdRef.Unpeeled(Ref.Storage.NEW, name, null));
		this.refdb = refdb;
		setCheckConflicting(false);
	}

	@Override
	protected RefDatabase getRefDatabase() {
		return refdb;
	}

	@Override
	protected Repository getRepository() {
		return refdb.getRepository();
	}

	@Override
	protected boolean tryLock(boolean deref) throws IOException {
		return false;
	}

	@Override
	protected void unlock() {
		// No locks are held here.
	}

	@Override
	protected Result doUpdate(Result desiredResult) {
		return Result.LOCK_FAILURE;
	}

	@Override
	protected Result doDelete(Result desiredResult) {
		return Result.LOCK_FAILURE;
	}

	@Override
	protected Result doLink(String target) {
		return Result.LOCK_FAILURE;
	}
}

==> org.eclipse.jgit-5.7.0.202003110725-r-sources.jar: org/eclipse/jgit/internal/storage/reftree/AlwaysFailUpdate.java <==
/*
 * Copyright (C) 2016, Google Inc. and others
 *
 * This program and the accompanying materials are made available under the
 * terms of the Eclipse Distribution License v. 1.0 which is available at
 * https://www.eclipse.org/org/documents/edl-v10.php.
 *
 * SPDX-License-Identifier: BSD-3-Clause
 */

package org.eclipse.jgit.internal.storage.reftree;

import java.io.IOException;

import org.eclipse.jgit.lib.ObjectIdRef;
import org.eclipse.jgit.lib.Ref;
import org.eclipse.jgit.lib.RefDatabase;
import org.eclipse.jgit.lib.RefUpdate;
import org.eclipse.jgit.lib.Repository;

/** Update that always rejects with {@code LOCK_FAILURE}. */
class AlwaysFailUpdate extends RefUpdate {
	private final RefTreeDatabase refdb;

	AlwaysFailUpdate(RefTreeDatabase refdb, String name) {
		super(new ObjectIdRef.Unpeeled(Ref.Storage.NEW, name, null));
		this.refdb = refdb;
		setCheckConflicting(false);
	}

	/** {@inheritDoc} */
	@Override
	protected RefDatabase getRefDatabase() {
		return refdb;
	}

	/** {@inheritDoc} */
	@Override
	protected Repository getRepository() {
		return refdb.getRepository();
	}

	/** {@inheritDoc} */
	@Override
	protected boolean tryLock(boolean deref) throws IOException {
		return false;
	}

	/** {@inheritDoc} */
	@Override
	protected void unlock() {
		// No locks are held here.
	}

	/** {@inheritDoc} */
	@Override
	protected Result doUpdate(Result desiredResult) {
		return Result.LOCK_FAILURE;
	}

	/** {@inheritDoc} */
	@Override
	protected Result doDelete(Result desiredResult) {
		return Result.LOCK_FAILURE;
	}

	/** {@inheritDoc} */
	@Override
	protected Result doLink(String target) {
		return Result.LOCK_FAILURE;
	}
}
